#import "../../../template.typ": apply-template
#show: apply-template
#set page(
  margin: auto,
  header: [Übungen für die Bioklausur am _26.09.2024_],
)
#set text(lang: "de")

// hier ist meine Farbgebung von Wörtern
#show "tRNA": text(blue)[tRNA]
#show "mRNA": text(red)[mRNA]
#show "Aminosäure": text(orange)[Aminosäure]
#show "Ribosom": text(green)[Ribosom]
#show "ZK": text[Zellkern]
#show "Synthese": text(rgb("#af0790"))[Synthese]

#outline(indent: 1.5em)

= Überblick des relevanten

- Transkription
- Translation
- Spleißen
- 3' und 5'

= DNA
hier handelt es sich vorerst nur um *Prokaryoten*

== Aufbau

- Basen
  - komplementäre Paare\
    Cytosin (C) — Guanin (G)\
    Adenin (A) — Thymin (T)

== Replikation

- *Helicase* → trennt die DNA entzwei, Replikationsgabel entsteht
- *kontinuierliche* Synthese
  - entlang des 3'-Ende
  - hier entsteht der _Leitstrang_
- *diskontinuierliche* Synthese
  - in Brocken, da hier das 5'-Ende freiliegt#footnote[und nur am 3'-Strich ansetzen kann] -> Okazaki-Fragmente
    - DNA-Ligase bindet diese
  - hier entsteht der _Folgestrang_
- *DNA-Polymerase* bindet freie Nukleotide an den originellen Strang
  - ist auf #sym.arrow.b angewiesen
- *Primer* → dieses Molekül zeigt wo die DNA-Polymerase starten muss
  - hierdurch wird auch markiert wo eine RNA beginnt → RNA-Primer

== Transkription

- eine mRNA bildet ein Gen
- Promotor → Basensequenz welcher den Anfang der Transkription anzeigt
- Terminator → Basensequenz welcher das Ende der Transkription zeigt
- RNA-Polymerase → entwindet Stränge der DNA vom _Promotor_ bis zum _Terminator_
- einer der beiden einzelnen DNA-Stränge gilt als Kopiervorlage → codogener Strang

Nach der Entwindung lagern sich RNA-Nucleotide an das 3'-Ende an, welche dann später von der RNA-Polymerase verbunden werden und letztlich die *mRNA* bilden.

mehrere Transkriptionen können zugleich für das selbe Gen zuständig sein.

== mRNA

mRNA → messeger-RNA\
tRNA → transfer-RNA\
rRNA → ribosomale RNA

*RNA* enthält statt _Thymin_ die Base _Uracil(U)_ #footnote[Also bindet sich A jetzt mit U]

- Triplett-Code → drei Basen sind für eine Aminosäure zuständig
  - wird auch *Codon* genannt
- eindeutig → jedes Codon ist für genau eine Aminosäure zuständig
- degeneriert → mehrere verschiedene Codons können in der selben Aminosäure resultieren
- kommafrei → Codons erfolgen lückenlos und ohne Leerstellen aufeinander
- nahezu universell → fast alle Lebewesen nutzen den genetischen Code

== Translation

Übersetzt mRNA in eine Polypeptidkette mit bestimmter Reihenfolge

- tRNA wird mit je einer Aminosäure beladen → tRNA-Synthase
  - Aminosäurebindungsstelle → hier kann sich die mRNA ans tRNA binden
    - besteht aus Anitcodons
    - übersetzt mRNA zu einer Aminosäure
- *Ribosome* → bestehen aus einer _großen_ un einer _kleinen Untereinheit_
  - _kleine Untereinheit_ → Bindungsstelle für mRNA, liest diese ab
  - _große Untereinheit_ → ist für Verknüpfung der Aminosäuren zuständig und hat drei Bindungsstellen für die tRNA-Moleküle und hat drei Stellen:
    - *A-Stelle* → Eingang des Ribosomen, bindet je eine _beladene_ tRNA
    - *P-Stelle* → verbindet Ribosom mit der Aminosäure der tRNA
    - *E-Stelle* → hier verlassen die entladenen tRNA das Ribosom

*Ablauf:*\
+ mRNA lagert sich an _kleine Untereinheit_ des Ribosoms an, welche sich in Richtung des 3'-Ende bewegt bis es auf das *Startcodon* _AUG_ trifft
+ tRNA lagert sich an das *Startcodon* an und die _große_ und _kleine Untereinheit_ verbinden sich
+ Aminosäure wird von der tRNA an der *P-Stelle* an die *A-Stelle* weitergegeben und verlässt das Ribosom an der *E-Stelle*
+ Prozess wiederholt sich bis auf ein *Stoppcodon* wie _UAA_, _UAG_ oder _UGA_ in der *A-Stelle* getroffen wird
+ Das fertige Polypeptid an der *A-Stelle* wird freigegeben

Wenn mehrere Ribosomen zugleich dasselbe mRNA-Molekül ablesen wird dies Polysomen genannt.

= Eukaryoten
bisher handelte es sich die ganze Zeit nur um *Prokaryoten*

== Unterschiede zu Prokaryoten

- enthält Nucleotid-Sequenzen die kein Polypeptid codieren → *Introns*
- codierende Nucleotid-Sequenzen → *Exons*

Aufgrund dieser beiden werden Eukaryoten auch _Mosaikgene_ genannt.

== Genexpression

- ist hier von einer Kernhülle umgeben → Transkription und Translation sind voneinander getrennt
- Gene werden zunächst in mRNA transkribiert → *prä-mRNA*, welche vorerst im ZK bleibt
- Basen werden an die beiden Enden geknüpft
  - 5'-Ende erhält modifizierte Form von Guanin → *cap-Struktur*\
    ⇒ schützt mRNA vor enzymatischen Abbau #footnote[hierbei handelt es sich um Enzyme welche zum regulieren von Stoffen im Körper eingesetzt werden und jede mRNA Abbauen könnte]<f-enzym> und erleichtert Anlangern an Ribosomen
  - 3'-Ende erhält bis zu 300-Adenin-Nucleotide → *Poly-A-Schwanz*\
    ⇒ erleichtert Export ins Cytoplasma und schützt vor enzymatischen Abbau #footnote(<f-enzym>)
- *Spleißen* → Introns werden aus der prä-mRNA herausgeschnitten
  - *alternative Spleißen* → _Introns_ können modifiatoren enthalten welche beim Spleißen verursachen das z.B. Intron in der mRNA verbleiben\
    ⇒ die möglichen proteincodierten Gene erhöhen sich #underline[hierdurch drastisch]
→ all dies ist teil der *Prozessierung*

#figure(
  image("../assets/excalidraw/Spleißen in Abfolge.excalidraw.png", height: 5%),
  caption: [Ablauf des Spleißen],
) <fig-spleißen>

Der Prozess danach läuft wiefolgt ab (wie in @fig-spleißen zu sehen ist):\
+ reife mRNA verlässt ZK
+ mRNA wird zu Polypeptidkette übersetzt (allerdings nicht _cap-Struktur_ oder _Poly-A-Schwanz_)
+ *posttranslationale Modifikation* findet statt

= Genmutation

// das hier konnte ich einfach von meinem vorherigen Eintrag nehmen lol

Wie beeinflussen Genmutationen die Proteinbiosynthese?

*Arten der Mutationen:*
- Genommutationen #sym.arrow Anzahl der Chromosomen
- Chromosomenmutationen #sym.arrow Struktur von Chromosomen wird geändert
- Genmutationen #sym.arrow ein einzelnen Gen wird geändert

*Typen der Mutationen:*
- Punktmutation #sym.arrow betrifft nur eine einzelne Base (b.z.w. Basenpaar)
  - Substitution #sym.arrow Basenpaar wird mit anderer ausgetauscht
  - Insertion #sym.arrow eine zusätzliche Basenpaar wird hinzugefügt
  - Deletion #sym.arrow ein Basenpaar wird verändert

*Substitutionen:*
- Missense-Mutation #sym.arrow Substitution erfolgt an erster und zweiter Stelle des Basentripplets\ #sym.arrow.double verändert massiv Aktivität
- stumme Mutation #sym.arrow erfolgt an dritter Stelle des Basentripplets\ #sym.arrow.double nicht so entscheidend wie die ersten beiden Basen des Basentripplets wichtiger sind #footnote[allerdings kann es trotzdem in einer anderen Aminosäure resultieren]
- Nonsense-Mutation #sym.arrow ein _Stopp-Codon_ entsteht\ #sym.arrow.double gebildetes Polypeptid ist meist funktionslos

*Insertionen und Deletionen:*
- Rasterschub-Mutationen #sym.arrow entsteht wenn kein vielfaches von drei gelöscht oder eingeschoben wird\ #sym.arrow.double Leseraster wird verschoben

Generell ist hier am wichtigsten, dass _die Struktur der mRNA erhalten bleibt_, was praktisch bedeutet das wenn eine Änderung erfolgt allerdings die Struktur identisch bleibt, es von wenig belang ist.

= Beispielbilder

#figure(
  image("../assets/excalidraw//BIO_Translation.excalidraw.png"),
  caption: [Beipiel von Spleißen],
)
